@@ -1,4 +1,4 @@
-/* $Id: impact.c,v 1.28.2.1.2.5 2011/01/18 17:51:37 imil Exp $ */
+/* $Id: impact.c,v 1.28.2.1.2.6 2011/01/20 15:00:29 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -385,6 +385,18 @@ count_samepkg(Plisthead *plisthead, const char *pkgname)
 	return count;
 }
 
+static uint8_t
+pkg_in_impact(Impacthead *impacthead, char *pkgname)
+{
+	Pkgimpact	*pimpact;
+
+	SLIST_FOREACH(pimpact, impacthead, next)
+		if (strncmp(pimpact->depname, pkgname, strlen(pkgname)) == 0)
+			return 1;
+
+	return 0;
+}
+
 Impacthead *
 pkg_impact(char **pkgargs)
 {
@@ -395,7 +407,7 @@ pkg_impact(char **pkgargs)
 	Pkgimpact	*pimpact, *tmpimpact;
 	Pkgdeptree	*pdp;
 	char		**ppkgargs, *pkgname = NULL;
-	int			exists, pkgcount;
+	int			pkgcount;
 
 	/* record local package list */
 	localplisthead = rec_pkglist(LOCAL_PKGS_QUERY);
@@ -441,15 +453,11 @@ pkg_impact(char **pkgargs)
 
 		/* parse dependencies for pkgname */
 		SLIST_FOREACH(pdp, &pdphead, next) {
-			exists = 0;
-			/* dependency is already present in impact list */
-			SLIST_FOREACH(pimpact, impacthead, next) {
-				if (strncmp(pimpact->depname, pdp->depname,
-						strlen(pdp->depname)) == 0)
-					exists = 1;
-			}
-			if (exists)
+
+			/* is dependency already recorded in impact list ? */
+			if (pkg_in_impact(impacthead, pdp->depname))
 				continue;
+
 			/* compare needed deps with local packages */
 			if (!deps_impact(impacthead, localplisthead,
 					remoteplisthead, pdp)) {
@@ -473,12 +481,15 @@ pkg_impact(char **pkgargs)
 		XSTRDUP(pdp->matchname, pkgname);
 		trunc_str(pdp->matchname, '-', STR_BACKWARD);
 
-		/* passing pkgname as depname */
-		XSTRDUP(pdp->depname, pkgname);
+		if (!pkg_in_impact(impacthead, pkgname)) {
+			/* passing pkgname as depname */
+			XSTRDUP(pdp->depname, pkgname);
 
-		deps_impact(impacthead, localplisthead, remoteplisthead, pdp);
+			deps_impact(impacthead, localplisthead, remoteplisthead, pdp);
+
+			XFREE(pdp->depname);
+		}
 
-		XFREE(pdp->depname);
 		XFREE(pdp->matchname);
 		XFREE(pdp);
 
