@@ -1,4 +1,4 @@
-/* $Id: pkglist.c,v 1.12.2.1.2.1 2011/01/16 22:25:21 imil Exp $ */
+/* $Id: pkglist.c,v 1.12.2.1.2.2 2011/01/18 16:26:58 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -329,7 +329,7 @@ end_expr(Plisthead *plisthead, const char *str)
 	/* expr was not a dewey pattern, it's a full package name,
 	 * strip the final dash if found
 	 */
-	if (!was_dep && (p = match_dep_ext(expr, "-")) != NULL) {
+	if (!was_dep && (p = strrchr(expr, '-')) != NULL) {
 		*p++ = DELIMITER; /* terminate expr */
 		*p = '\0';
 	}
